==> haskell-hledger-lib-1.32.1-121-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hledger-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger-lib
version:              1.32.1
visibility:           public
id:                   hledger-lib-1.32.1-8gyDtvGXhKT8ZrGneTIzYS
key:                  hledger-lib-1.32.1-8gyDtvGXhKT8ZrGneTIzYS
license:              GPL-3.0-only
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             A library providing the core functionality of hledger
description:
    This library contains hledger'\''s core functionality.
    It is used by most hledger* packages so that they support the same
    command line options, file formats, reports, etc.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting.

    See also:

    - https://hledger.org - hledger'\''s home page

    - https://hledger.org/dev.html - starting point for hledger'\''s developer docs

    - https://hackage.haskell.org/package/hledger-lib/docs/Hledger.html - starting point for hledger'\''s haddock docs

category:             Finance
abi:                  878bf8dc10b4e4802ad536fd67f4a34d
exposed:              True
exposed-modules:
    Hledger Hledger.Data Hledger.Data.Account Hledger.Data.AccountName
    Hledger.Data.Amount Hledger.Data.Balancing Hledger.Data.Dates
    Hledger.Data.Errors Hledger.Data.Journal Hledger.Data.JournalChecks
    Hledger.Data.JournalChecks.Ordereddates
    Hledger.Data.JournalChecks.Uniqueleafnames Hledger.Data.Json
    Hledger.Data.Ledger Hledger.Data.Period
    Hledger.Data.PeriodicTransaction Hledger.Data.Posting
    Hledger.Data.RawOptions Hledger.Data.StringFormat
    Hledger.Data.Timeclock Hledger.Data.Transaction
    Hledger.Data.TransactionModifier Hledger.Data.Types
    Hledger.Data.Valuation Hledger.Query Hledger.Read
    Hledger.Read.Common Hledger.Read.CsvReader Hledger.Read.CsvUtils
    Hledger.Read.InputOptions Hledger.Read.JournalReader
    Hledger.Read.RulesReader Hledger.Read.TimeclockReader
    Hledger.Read.TimedotReader Hledger.Reports
    Hledger.Reports.AccountTransactionsReport
    Hledger.Reports.BalanceReport Hledger.Reports.BudgetReport
    Hledger.Reports.EntriesReport Hledger.Reports.MultiBalanceReport
    Hledger.Reports.PostingsReport Hledger.Reports.ReportOptions
    Hledger.Reports.ReportTypes Hledger.Utils Hledger.Utils.Debug
    Hledger.Utils.IO Hledger.Utils.Parse Hledger.Utils.Regex
    Hledger.Utils.String Hledger.Utils.Test Hledger.Utils.Text
    Text.Tabular.AsciiWide

hidden-modules:
    Text.Megaparsec.Custom Text.WideString Paths_hledger_lib

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hledger-lib-1.32.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hledger-lib-1.32.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hledger-lib-1.32.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hledger-lib
hs-libraries:         HShledger-lib-1.32.1-8gyDtvGXhKT8ZrGneTIzYS
depends:
    Decimal-0.5.2-79E3HPvJE9wIJQu9E1TEVT
    Glob-0.10.2-5t0RvtmSvyZLyKqlQQxl7u
    aeson-2.1.2.1-GOr0sGsn8HVJzt9KhewtB0
    aeson-pretty-0.8.10-D5Th2sszhWWBt58oyBlAJB
    ansi-terminal-1.0.2-D46JaHr1BfPBLAK7nuv4I array-0.5.4.0
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    blaze-markup-0.8.3.0-EXIdF6gaJs7HROOmQDdLmZ bytestring-0.11.5.3
    call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    cassava-0.5.3.2-3kQEydgDNwL3aYF4wMBiY3
    cassava-megaparsec-2.1.1-1Lxua6CdbVDLsceKq5HLcE
    cmdargs-0.10.22-KMcxPO0UszDDPT8hI73uO5
    colour-2.3.6-Cnp0EOFOdvOB15fkdB7GSC containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    directory-1.3.7.1 doclayout-0.4.0.1-Fog2Y49RdEoCvFPU8Vwg6H
    extra-1.7.16-JJdQ9eFtkoVDmjYz0qVuVR
    file-embed-0.0.15.0-7OnjuFj6gBM9fqBKJCVXdU filepath-1.4.2.2
    hashtables-1.3.1-ELnOlpgh9f1FmCSZRNEBKZ
    megaparsec-9.6.1-747qApo3GKN165PbKLSk2e
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-th-0.4.3.17-Vfga0HXPTS6SXD3NuXqZ3 mtl-2.2.2
    pager-0.1.1.0-GDiXQZApy3SK6iIZ8amsHH
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav
    pretty-simple-4.1.3.0-LbgWnolD8n2JAsBmbFK90v
    regex-tdfa-1.3.2.4-DyGMbh1NpFc9rSkmhAEdJe
    safe-0.3.21-4RbCGR2deY91o6dlI4zODz
    tabular-0.2.2.8-GPlaI3PukxDKI4c6j3m1vm
    tasty-1.4.3-F9OqaL2hK2T3ibNso1WybZ
    tasty-hunit-0.10.1-3aZMZdK4qT047UWVyLNzkK template-haskell-2.19.0.0
    terminal-size-0.3.4-G9QKE0nIH70HWdqrMvHn0A text-2.0.2
    text-ansi-0.3.0-3A4bC0tCEdm4GOSL9Gunhl time-1.12.2
    timeit-2.0-GSLifhpRLI5Gr54jWRx5t0 transformers-0.5.6.2
    uglymemo-0.1.0.1-8AX9zjlFnnmIrnTboBgOzO
    unordered-containers-0.2.20-Jl6TkouWI2i1D1jczNV0uv
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-hledger-lib/html/hledger-lib.haddock
haddock-html:         /usr/share/doc/haskell-hledger-lib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hledger-lib-1.32.1-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hledger-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger-lib
version:              1.32.1
visibility:           public
id:                   hledger-lib-1.32.1-Lm5DBLxOgmC9X8dp0BBMVL
key:                  hledger-lib-1.32.1-Lm5DBLxOgmC9X8dp0BBMVL
license:              GPL-3.0-only
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             A library providing the core functionality of hledger
description:
    This library contains hledger'\''s core functionality.
    It is used by most hledger* packages so that they support the same
    command line options, file formats, reports, etc.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting.

    See also:

    - https://hledger.org - hledger'\''s home page

    - https://hledger.org/dev.html - starting point for hledger'\''s developer docs

    - https://hackage.haskell.org/package/hledger-lib/docs/Hledger.html - starting point for hledger'\''s haddock docs

category:             Finance
abi:                  ece9656cf0ac14a0cd23964325b81840
exposed:              True
exposed-modules:
    Hledger Hledger.Data Hledger.Data.Account Hledger.Data.AccountName
    Hledger.Data.Amount Hledger.Data.Balancing Hledger.Data.Dates
    Hledger.Data.Errors Hledger.Data.Journal Hledger.Data.JournalChecks
    Hledger.Data.JournalChecks.Ordereddates
    Hledger.Data.JournalChecks.Uniqueleafnames Hledger.Data.Json
    Hledger.Data.Ledger Hledger.Data.Period
    Hledger.Data.PeriodicTransaction Hledger.Data.Posting
    Hledger.Data.RawOptions Hledger.Data.StringFormat
    Hledger.Data.Timeclock Hledger.Data.Transaction
    Hledger.Data.TransactionModifier Hledger.Data.Types
    Hledger.Data.Valuation Hledger.Query Hledger.Read
    Hledger.Read.Common Hledger.Read.CsvReader Hledger.Read.CsvUtils
    Hledger.Read.InputOptions Hledger.Read.JournalReader
    Hledger.Read.RulesReader Hledger.Read.TimeclockReader
    Hledger.Read.TimedotReader Hledger.Reports
    Hledger.Reports.AccountTransactionsReport
    Hledger.Reports.BalanceReport Hledger.Reports.BudgetReport
    Hledger.Reports.EntriesReport Hledger.Reports.MultiBalanceReport
    Hledger.Reports.PostingsReport Hledger.Reports.ReportOptions
    Hledger.Reports.ReportTypes Hledger.Utils Hledger.Utils.Debug
    Hledger.Utils.IO Hledger.Utils.Parse Hledger.Utils.Regex
    Hledger.Utils.String Hledger.Utils.Test Hledger.Utils.Text
    Text.Tabular.AsciiWide

hidden-modules:
    Text.Megaparsec.Custom Text.WideString Paths_hledger_lib

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hledger-lib-1.32.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hledger-lib-1.32.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hledger-lib-1.32.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hledger-lib
hs-libraries:         HShledger-lib-1.32.1-Lm5DBLxOgmC9X8dp0BBMVL
depends:
    Decimal-0.5.2-EvRcqUIPT9uHP0LYQhNTSg
    Glob-0.10.2-9hWgNPk7TOD9yx3wvaRjo6
    aeson-2.1.2.1-LS8mizUYnpf1U9zpV4sjcf
    aeson-pretty-0.8.10-CCkxQiITOw1DT6rZMnwiIR
    ansi-terminal-1.0.2-6TxOAUbfOQrDbPnWIRhRhS array-0.5.4.0
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    blaze-markup-0.8.3.0-4zGQB5UMO8P5hF725cGajZ bytestring-0.11.5.3
    call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    cassava-0.5.3.2-yIM8AbTVf29Upq1My9xEE
    cassava-megaparsec-2.1.1-IEA3bfTYqsH7o0WZJaxm9Z
    cmdargs-0.10.22-KMcxPO0UszDDPT8hI73uO5
    colour-2.3.6-9rTtk69Pc3k5Ik3SUsZeCb containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    directory-1.3.7.1 doclayout-0.4.0.1-JhhFAgNLi9YEWEfw5R1V9v
    extra-1.7.16-5m7TC0OmR1yJEj0luDg7V3
    file-embed-0.0.15.0-7OnjuFj6gBM9fqBKJCVXdU filepath-1.4.2.2
    hashtables-1.3.1-G3EA1xJGQUUIWkBGvQRelH
    megaparsec-9.6.1-KkOPmPbRCEmCvB2XbKT9En
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-th-0.4.3.17-Vfga0HXPTS6SXD3NuXqZ3 mtl-2.2.2
    pager-0.1.1.0-44DWzWJt0K3Kd3ZFzHdoR5
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav
    pretty-simple-4.1.3.0-LZgLKj6ccQI7Np83QXbC6H
    regex-tdfa-1.3.2.4-AAuM6ZM4tbzHRXDs6OdINo
    safe-0.3.21-D0Qa6qmXFrgLhocJR17U7j
    tabular-0.2.2.8-GPlaI3PukxDKI4c6j3m1vm
    tasty-1.4.3-HK16IWl2qZuAE1kQP7GLN3
    tasty-hunit-0.10.1-4olJEdoQaAQ1sPVsKcqoD template-haskell-2.19.0.0
    terminal-size-0.3.4-G9QKE0nIH70HWdqrMvHn0A text-2.0.2
    text-ansi-0.3.0-3Yi4juPAhH5IhfAbuYjoCT time-1.12.2
    timeit-2.0-GSLifhpRLI5Gr54jWRx5t0 transformers-0.5.6.2
    uglymemo-0.1.0.1-8AX9zjlFnnmIrnTboBgOzO
    unordered-containers-0.2.20-vB8Yx6KwyeBrT13JKFJ0i
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-hledger-lib/html/hledger-lib.haddock
haddock-html:         /usr/share/doc/haskell-hledger-lib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
